# Hipersim

## Introduction
Hipersim is a collection of tools for computationally-efficient simulation of Wind Energy problems using statistical and machine learning methods. Currently, the package contains the following submodules:

- **turbgen**: 
    - Generation of 3D frozen turbulence fields ("turbulence boxes") with the Mann turbulence spectrum
    - Constrained turbulence field generation and application of constraints on pre-generated turbulence fields

- **surrogates**:
    - A feedforward neural network toolbox, training and evaluation of feedforward neural networks. 

## Installation
Hipersim is registered as installable Python package in PyPi.org. Installation happens automatically with the following command:

pip install hipersim

## References

## License
Hipersim uses the MIT License.
